package com.jeeplus.human.enrollment.enrollmentRegistration.controller;

import com.jeeplus.human.enrollment.enrollmentRegistration.domain.EnrollmentCertificateInfo;
import com.jeeplus.human.enrollment.enrollmentRegistration.domain.EnrollmentSkillInfo;
import com.jeeplus.human.enrollment.enrollmentRegistration.service.EnrollmentCertificateInfoService;
import com.jeeplus.human.enrollment.enrollmentRegistration.service.EnrollmentSkillInfoService;
import com.jeeplus.logging.annotation.ApiLog;
import com.jeeplus.logging.constant.enums.LogTypeEnum;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

/**
 * @author 王强
 * @version 1.0
 */
@Slf4j
@RestController
@Api("专业技能")
@RequestMapping(value = "/skillInfo")
public class EnrollmentSkillInfoController {

    @Resource
    private EnrollmentSkillInfoService service;


    /**
     * 保存专业技能
     * @return
     */
    @ApiLog(value = "保存专业技能", type = LogTypeEnum.SAVE)
    @PostMapping("save")
    public ResponseEntity save(@Valid @RequestBody EnrollmentSkillInfo info) throws Exception {
        service.saveOrUpdateInfo(info);
        return ResponseEntity.ok ("操作成功");
    }

    /**
     * 删除专业技能
     * @return
     */
    @ApiLog(value = "删除专业技能", type = LogTypeEnum.SAVE)
    @PostMapping("delete")
    public ResponseEntity<String> delete(@Valid @RequestBody EnrollmentSkillInfo info) throws Exception {
        service.removeById(info.getId());
        return ResponseEntity.ok ("操作成功");
    }

    /**
     * 专业技能
     * @return
     */
    @ApiLog(value = "专业技能", type = LogTypeEnum.SAVE)
    @GetMapping("list")
    public ResponseEntity<List<EnrollmentSkillInfo>> findList(EnrollmentSkillInfo info) throws Exception {
        List<EnrollmentSkillInfo> list = service.findByUserId(info.getUserId(),"5");
        return ResponseEntity.ok (list);
    }

    /**
     * 根据id查询专业技能
     * @return
     */
    @ApiLog(value = "根据id查询专业技能信息", type = LogTypeEnum.SAVE)
    @GetMapping("findById")
    public ResponseEntity<EnrollmentSkillInfo> findById(EnrollmentSkillInfo info) throws Exception {
        EnrollmentSkillInfo res = service.findById(info.getId());
        return ResponseEntity.ok (res);
    }
}
