package com.jeeplus.human.enrollment.enrollmentRegistration.controller;

import com.jeeplus.human.enrollment.enrollmentRegistration.domain.EnrollmentEduInfo;
import com.jeeplus.human.enrollment.enrollmentRegistration.domain.EnrollmentWorkInfo;
import com.jeeplus.human.enrollment.enrollmentRegistration.service.EnrollmentEduInfoService;
import com.jeeplus.human.enrollment.enrollmentRegistration.service.EnrollmentWorkInfoService;
import com.jeeplus.logging.annotation.ApiLog;
import com.jeeplus.logging.constant.enums.LogTypeEnum;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.validation.Valid;
import java.util.List;

/**
 * @author 王强
 * @version 1.0
 */
@Slf4j
@RestController
@Api("工作经历")
@RequestMapping(value = "/workInfo")
public class EnrollmentWorkInfoController {

    @Resource
    private EnrollmentWorkInfoService service;


    /**
     * 保存教育经历
     * @return
     */
    @ApiLog(value = "保存工作经历", type = LogTypeEnum.SAVE)
    @PostMapping("save")
    public ResponseEntity save(@Valid @RequestBody EnrollmentWorkInfo info) throws Exception {
        service.saveOrUpdateWorkInfo(info);
        return ResponseEntity.ok ("操作成功");
    }

    /**
     * 删除教育经历
     * @return
     */
    @ApiLog(value = "删除工作经历", type = LogTypeEnum.SAVE)
    @PostMapping("delete")
    public ResponseEntity<String> delete(@Valid @RequestBody EnrollmentWorkInfo info) throws Exception {
        service.removeById(info.getId());
        return ResponseEntity.ok ("操作成功");
    }

    /**
     * 教育经历列表
     * @return
     */
    @ApiLog(value = "工作经历列表", type = LogTypeEnum.SAVE)
    @GetMapping("list")
    public ResponseEntity<List<EnrollmentWorkInfo>> findList(EnrollmentWorkInfo info) throws Exception {
        List<EnrollmentWorkInfo> list = service.findByUserId(info.getUserId(),"5");
        return ResponseEntity.ok (list);
    }

    /**
     * 根据id查询教育经历信息
     * @return
     */
    @ApiLog(value = "根据id查询工作经历信息", type = LogTypeEnum.SAVE)
    @GetMapping("findById")
    public ResponseEntity<EnrollmentWorkInfo> findById(EnrollmentWorkInfo info) throws Exception {
        EnrollmentWorkInfo res = service.findById(info.getId());
        return ResponseEntity.ok (res);
    }
}
